==> scipion-em-relion-4.0.2.tar.gz: scipion-em-relion-4.0.2/relion/viewers/__init__.py <==
# ******************************************************************************
# *
# * Authors:     Grigory Sharov     (gsharov@mrc-lmb.cam.ac.uk)
# *
# * MRC Laboratory of Molecular Biology, MRC-LMB
# *
# * This program is free software; you can redistribute it and/or modify
# * it under the terms of the GNU General Public License as published by
# * the Free Software Foundation; either version 3 of the License, or
# * (at your option) any later version.
# *
# * This program is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# * GNU General Public License for more details.
# *
# * You should have received a copy of the GNU General Public License
# * along with this program; if not, write to the Free Software
# * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
# * 02111-1307  USA
# *
# *  All comments concerning this program package may be sent to the
# *  e-mail address 'scipion@cnb.csic.es'
# *
# ******************************************************************************

from .viewer_base import *
from .viewer_ctfrefine import ProtCtfRefineViewer
from .viewer_postprocess import PostprocessViewer
from .viewer_motioncor import RelionMotioncorrViewer
from .viewer_locres import RelionLocalResViewer
from .viewer_polishing import RelionPolishViewer
from .viewer_multibody import MultibodyViewer
from .viewer_reconstruct import ReconstructViewer

==> scipion-em-relion-4.0.17.tar.gz: scipion-em-relion-4.0.17/relion/viewers/__init__.py <==
# ******************************************************************************
# *
# * Authors:     Grigory Sharov     (gsharov@mrc-lmb.cam.ac.uk)
# *
# * MRC Laboratory of Molecular Biology, MRC-LMB
# *
# * This program is free software; you can redistribute it and/or modify
# * it under the terms of the GNU General Public License as published by
# * the Free Software Foundation; either version 3 of the License, or
# * (at your option) any later version.
# *
# * This program is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# * GNU General Public License for more details.
# *
# * You should have received a copy of the GNU General Public License
# * along with this program; if not, write to the Free Software
# * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
# * 02111-1307  USA
# *
# *  All comments concerning this program package may be sent to the
# *  e-mail address 'scipion@cnb.csic.es'
# *
# ******************************************************************************

from .viewer_base import *
from .viewer_ctfrefine import ProtCtfRefineViewer
from .viewer_postprocess import PostprocessViewer, ProtFSCViewer
from .viewer_motioncor import RelionMotioncorrViewer
from .viewer_locres import RelionLocalResViewer
from .viewer_polishing import RelionPolishViewer
from .viewer_multibody import MultibodyViewer
from .viewer_reconstruct import ReconstructViewer
